#
# spec file for package sysstat
#
# Copyright (c) 2011 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

# norootforbuild


Name:           sysstat
Version:        9.0.6.1
Release:        14.15.1
Summary:        Sar and Iostat Commands for Linux
Source:         http://pagesperso-orange.fr/sebastien.godard/%{name}-%{version}.tar.bz2
Source1:        isag.desktop
Source2:        sysstat.cron.suse
Source3:        sysstat.init.suse
# PATCH-FIX-OPENSUSE should be upstreamed
# add locking to scripts sa1 and sa2 (bnc#7861)
Patch0:         sysstat-8.1.6-sa1sa2lock.diff
# PATCH-FIX-OPENSUSE should be upstreamed
# use getpagesize() instead of kb_shift for hugetable archs
Patch2:         sysstat-8.0.4-pagesize.diff
# PATCH-FIX-OPENSUSE use /etc/sysstat for config files
# instead of /etc/sysconfig since the files do not match
# the format used there (should be configure option)
Patch3:         sysstat-8.0.4-sysconfdir.diff
# PATCH-FIX-OPENSUSE remove the unconditional stripping
# we possibly want a debuginfo package
Patch4:         sysstat-do-not-strip.patch
# PATCH-FIX-OPENSUSE avoid build dates in generated files
Patch5:         sysstat-9.0.4-no-build-date.patch
Url:            http://pagesperso-orange.fr/sebastien.godard/
Group:          System/Monitoring
License:        GNU General Public License version 2 or later (GPL v2 or later)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
Requires:       procmail gettext
PreReq:         %insserv_prereq 
PreReq:         %fillup_prereq

BuildRequires:  findutils sed update-desktop-files

%description
Sar and Iostat commands for Linux. The sar command collects and reports
system activity information. The iostat command reports CPU statistics
and I/O statistics for TTY devices and disks.  The information
collected by sar and iostat can be saved in a binary file for future
inspection. Both commands now support SMP machines when displaying CPU
utilization.


Authors:
--------
    Sebastien Godard <sebastien.godard@wanadoo.fr>

%package isag
License:        GNU General Public License version 2 or later (GPL v2 or later)
Summary:        Interactive System Activity Grapher for sysstat
Requires:       sysstat = %{version}
Requires:       gnuplot tk
Group:          System/Monitoring

%description isag
This package includes the isag command, which graphically displays the
system activity data stored in a binary data produced by a sar command
from a sysstat package.


Authors:
--------
    Sebastien Godard <sebastien.godard@wanadoo.fr>

%prep
%setup -q
%patch0
%patch2
%patch3
%patch4 -p1
%patch5
cp %{SOURCE1} %{SOURCE2} %{SOURCE3} .

%build
export conf_dir="%{_sysconfdir}/sysstat"
export sa_lib_dir="%{_libdir}/sa"
export cron_owner=root
export LFLAGS="-L. -lsyscom"
%configure \
    --enable-nls \
    --disable-smp-race \
    --enable-man-group
make %{?_smp_mflags}

%install
mkdir -p $RPM_BUILD_ROOT%{_localstatedir}/log/sa $RPM_BUILD_ROOT%{_sbindir}
make DESTDIR=$RPM_BUILD_ROOT install
install -D -m 0644 isag.desktop $RPM_BUILD_ROOT%{_datadir}/applications/isag.desktop
%suse_update_desktop_file isag
cp contrib/isag/isag $RPM_BUILD_ROOT%{_bindir}
cp contrib/isag/isag.1 $RPM_BUILD_ROOT%{_mandir}/man1
rm -rf $RPM_BUILD_ROOT/usr/share/doc/sysstat*
install -D -m 0755 sysstat.cron.suse $RPM_BUILD_ROOT%{_sysconfdir}/sysstat/sysstat.cron
install -D -m 0755 sysstat.init.suse $RPM_BUILD_ROOT%{_sysconfdir}/init.d/boot.sysstat
# change /usr/lib to /usr/lib64 or something else when needed
if [ "%{_libdir}" != "/usr/lib" ]; then
    sed -i 's:/usr/lib/:%{_libdir}/:g' $RPM_BUILD_ROOT%{_sysconfdir}/init.d/boot.sysstat $RPM_BUILD_ROOT%{_sysconfdir}/sysstat/sysstat.cron
fi
ln -s %{_sysconfdir}/init.d/boot.sysstat $RPM_BUILD_ROOT%{_sbindir}/rcsysstat
%find_lang %{name}
install -d $RPM_BUILD_ROOT%{_localstatedir}/lock/sa

%preun
%{stop_on_removal boot.sysstat}
[ "$1" -gt 0 ] || rm -f %{_localstatedir}/log/sa/*

%post
%{fillup_and_insserv boot.sysstat}

%postun
%{insserv_cleanup}

%clean
%__rm -rf "%{buildroot}"

%files -f "%{name}.lang"
%defattr(-,root,root)
%doc CHANGES COPYING CREDITS FAQ README TODO
%doc %{_mandir}/man1/*
%doc %{_mandir}/man8/*
%exclude %{_mandir}/man1/isag*
%dir %{_sysconfdir}/sysstat
%config %{_sysconfdir}/sysstat/sysstat
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysstat/sysstat.cron
%attr(644,root,root) %config(noreplace) %{_sysconfdir}/sysstat/sysstat.ioconf
%attr(755,root,root) %{_sysconfdir}/init.d/boot.sysstat
%{_bindir}/*
%{_sbindir}/*
%exclude %{_bindir}/isag
%{_libdir}/sa
%dir %{_localstatedir}/lock/sa
%dir %{_localstatedir}/log/sa

%files isag
%defattr(-,root,root)
%doc contrib/isag/README-isag
%doc %{_mandir}/man1/isag*
%{_bindir}/isag
%{_datadir}/applications/isag.desktop

%changelog
* Thu Oct 27 2011 puzel@suse.com
- create the report before midnight (bnc#720609)
* Sun Oct 31 2010 jengelh@medozas.de
- Use %%_smp_mflags
* Wed Oct 20 2010 ro@suse.de
- update to 9.0.6.1
  * Because of a change in /proc/interrupts file format, mpstat
    was no longer counting the proper number of interrupts. This
    is now fixed.
  * iostat manual page updated.
  * NLS updated.
- update to 9.0.6
  * "sadf -x" now takes into account options -s and -e (which
    specify a starting and ending time) and also interval and
    count parameters [DEBIAN bug#546259].
  * Option -C added to sadf. Use it to tell sadf to display comments
    present in file (also works with XML format).
  * sar and sadf sometimes didn't handle COMMENT records properly.
    This is now fixed.
  * XML output (displayed by sadf -x) modified for kernel tables
    statistics.
  * XSD and DTD documents updated.
  * [Yibin Shen]: HZ variable was not explicitly set in sadc.c. This is now fixed.
  * [Lans Carstensen]: sargraph added (sargraph is a shell script used to make graphs
    based on sadf XML output).
  * sadf manual page updated.
  * FAQ updated.
  * NLS updated.
  * CREDITS file updated.
- update to 9.0.5
  * sysstat should now be able to pretty print device names whose
    minor numbers are greater than or equal to 256. (Tests have
    been made on a large 26TB RHEL5/PP Linux cluster.)
  * sadc manual page updated.
  * NLS updated.
  * FAQ updated.
* Sun Aug 29 2010 cristian.rodriguez@opensuse.org
- Do not hardcode build dates, make build-compare happy
* Fri May 28 2010 puzel@novell.com
- add sysstat-do-not-strip.patch
* Wed Aug  5 2009 prusnak@suse.cz
- updated to 9.0.4
  * [Jonathan Kamens]: Fix double free/memory corruption bug
    with sadc.
  * [Jeroen Roovers]: Get entirely rid of implicit rule for
    libsyscom.a in Makefile to fix a problem with parallel
    execution.
  * sysstat.ioconf configuration file updated.
* Wed Jun 10 2009 prusnak@suse.cz
- merge some changes from package in server:monitoring project
* Fri May 29 2009 prusnak@suse.cz
- updated to 9.0.3
  * [Michael Blakeley]: Option -z added to iostat. This option
    tells iostat to omit output for any devices for which there
    was no activity during the sample period.
  * [Tomasz Pala]: Fix mpstat where interrupt values should be
    read as unsigned integers.
  * sar -n ALL didn't select IPv6 statistics. This is now fixed.
  * iostat, sar and mpstat manual pages updated.
  * sadf -x now displays file creation date.
  * XSD and DTD documents updated.
  * NLS updated. Latvian translation added.
  * CREDITS file updated.
  * Code cleaned.
- updated to 9.0.2
  * sadc can now collect partition statistics in addition to disk ones.
    Keywords XDISK and XALL have been added to -S option.
  * Fixed a memory corruption in pidstat and iostat. This corruption
    could happen when a list of comma-separated values following
    option -p was entered on the command line.
  * configure now takes into account a new variable named rcdir.
    This variable may be used to specify the directory where
    startup scripts will be installed.
  * The value of directory for installing documentation files
    can now be set with configure's --docdir option.
  * Fixed a small bug in activity.c file, where there was a
    missing semicolon between two fields.
  * sar and sadc manual pages updated.
  * NLS updated.
  * CREDITS file updated.
* Mon Mar  9 2009 prusnak@suse.cz
- updated to 9.0.1
  * Fix a crash with sar where a pointer was freed twice.
  * NLS updated.
  * sar manual page updated.
  * CREDITS file updated.
* Mon Mar  2 2009 prusnak@suse.cz
- updated to 9.0.0
  * Option -m added to sar. This option is intended to display
    power management statistics. At the present time, only
    CPU frequency statistics are available.
  * sadc updated: Option "-S POWER" tells sadc to collect power
    management statistics.
  * sadf command updated to take into account power management
    statistics.
  * [Mike Harvey]: No longer truncate the interval of time to
    32 bits, as this may cause some problems when displaying
    average values statistics on machines with hundreds of CPU.
  * read_uptime(): Cast values read from /proc/uptime to
    unsigned long long.
  * Fixed a small bug in sar where it didn't parse arguments
    properly when some options were entered in a specific order.
  * sadc and sar manual pages updated.
  * XSD and DTD documents updated.
  * FAQ updated.
  * NLS updated.
  * Code cleaned. Makefile cleaned.
* Fri Sep 26 2008 prusnak@suse.cz
- changed parameter "-d" to "-S ALL" in crontab to match the new syntax
* Mon Sep  8 2008 prusnak@suse.cz
- fixed german translation
* Tue Aug 19 2008 prusnak@suse.cz
- updated to 8.1.5:
  - changes too numerous to list (see CHANGES file)
- fix missing --boot parameter in init script [bnc#378874]
- fixed disc statistics logging [bnc#407004]
* Thu Jun 26 2008 werner@suse.de
- No patch for SuSE stuff
* Thu Jun 19 2008 werner@suse.de
- Add missing Provides to the init script
* Wed Apr  2 2008 prusnak@suse.cz
- do not remove log files when package is updated [bnc#371994]
* Tue Jan  8 2008 prusnak@suse.cz
- updated to 8.0.4:
  * Removed a 'packed' attribute in pidstat.h that generated
    a warning with gcc 4.1.1.
  * Take account of all memory zone types when calculating
    pgscank, pgscand and pgsteal displayed by sar -B.
  * XML Schema added. Useful with sadf option -x.
  * sadc and sadf manual pages updated.
  * NLS updated: Dutch translation added.
  * NLS updated: Brazilian Portuguese translation added.
  * NLS updated: Vietnamese translation added.
  * NLS updated: Kirghiz translation added.
  * NLS updated: Added a PO template file in nls directory.
    Makefile modified to enable PO files update.
  * sccsid string now also includes package name and version number.
  * Makefile updated: Startup links are named S01xxx instead of S03xxx
    to be consistent with chkconfig values.
  * Various spelling fixes.
  * CREDITS file updated.
* Tue Nov 20 2007 prusnak@suse.cz
- updated to 8.0.3
  * mpstat and sar didn't parse /proc/interrupts correctly when
    some CPUs had been disabled. This is now fixed.
  * fixed a bug in pidstat where a confusion between PID and TID
    could sometimes happen, resulting in erroneous statistics
    values being displayed.
  * iconfig script updated: Help for --enable-compress-manpg
    parameter is now available, help for --enable-install-cron
    parameter updated, added parameter cron_interval.
  * sa2 shell script can now compress sar data files using bzip2.
  * Makefile updated: Now also remove sysstat.crond.sample.in.
    Documentation is installed in $prefix/share/doc/ instead of
    $prefix/doc/ directory.
  * isag updated
  * FAQ updated
  * CREDITS file updated
  * sysstat's URL updated
* Tue Oct 30 2007 prusnak@suse.cz
- updated to 8.0.2
  * option -w added to pidstat. pidstat can now display task
    switching activity
  * fixed a memory leak in pidstat that was triggered when
    reading stats for threads
  * fixed a bug where device names were incorrectly displayed by
    sar -d or sar -dp
  * when using option -o, sar now saves by default all the
    statistics into the file, including interrupts and disks
    statistics (interrupts and disks statistics remain optional
    when using sadc)
* Tue Oct 16 2007 prusnak@suse.cz
- added boot.clock to Require-Start in initscript [#333793]
* Tue Oct  2 2007 prusnak@suse.cz
- update to 8.0.1
  * Option -t added to pistat. pidstat can now display stats for
    every thread (TID) of a process.
  * pidstat's option -T CHILD now reports global statistics for
    selected tasks and all their children (and not only for the
    children).
  * pidstat now reads VSZ and RSS values from /proc/#/stat instead
    of /proc/#/status.
  * Fixed a rare parallel make issue creating archive libsyscom.a
    [GENTOO bug #193208].
  * pidstat manual page updated.
  * SCCS identification string added to all commands.
  * NLS updated.
  * Code cleaned.
  * CREDITS file updated.
- altered pagesize.diff
* Tue Sep 25 2007 prusnak@suse.cz
- update to 8.0.0
  * WARNING: Daily data files format has changed, and is *not*
    compatible with the previous one! [0x216e]
  * pidstat command improved. It is now able to report CPU and
    page fault statistics for the child processes of a task.
  * Option -T added to pidstat. This option tells pidstat if
    statistics are to be reported for tasks (which is the default)
    or for their children.
  * Fixed a security flaw in sysstat startup script (CVE-2007-3852).
  * Removed super*, dquot* and rtsig* fields from sar -v.
    They were made obsolete in Linux kernels 2.6.
  * Fields file-sz and inode-sz from sar -v renamed in file-nr
    and inode-nr.
  * Added field pty-nr (number of pseudo-terminals) to sar -v.
  * Added field tcp-tw (number of sockets in TIME_WAIT state)
    to sar -n SOCK.
  * sar and sadf updated so that they can properly extract records
    (with their options -s and -e) from a file containing data for
    two consecutive days.
  * Added option "--enable-install-isag" to "configure" to enable
    the user to install isag script.
  * Fixed a typo in iconfig script: The user was unable to specify
    the crontab owner.
  * Manual pages updated
  * Sysstat DTD file updated
  * isag updated
* Tue Jul 10 2007 prusnak@suse.cz
- update to 7.1.6
  * new VM paging metrics added to sar
  * options -x and -X have been removed from sar, use pidstat instead
  * sar updated to avoid overflow when computing some average values
* Tue Jun 12 2007 prusnak@suse.cz
- updated to 7.1.5
- dropped obsolete patches
  * filelen.patch (included in update)
* Tue Jun  5 2007 prusnak@suse.cz
- fixed init-script and crontab files on 64bit archs [#280096]
* Wed May  2 2007 prusnak@suse.cz
- update to 7.1.4:
  * added new command "pidstat" aimed at displaying per-process statistics
  * added -N option to iostat
  - option enables the user to query any device-mapper devices for their
    registered device name
  * fixed a small memory leak in readp_uptime() function
  * stricter syntax checking for iostat
  * sar -dp now displays the device as "devM-N" (instead of "nodev") when it
    can't find its real name in sysstat.ioconf file
  * iostat -t now also takes into account the value of environment
    variable S_TIME_FORMAT
  * manual pages now take into account variables defined by "configure"
  * isag now takes into account variables defined by "configure"
  * "configure" now determines automatically whether workaround for SMP race
    is needed (SMP kernels 2.2.15 and older only)
* Tue Apr 17 2007 prusnak@suse.cz
- splitted isag utility to separate subpackage sysstat-isag
  * users will not be forced to install gnuplot (and X stuff) if
    they do not want to
* Tue Apr 17 2007 prusnak@suse.cz
- update to 7.1.3
  * fixed bug in hotplug cpu support
  * better support for keeping sar logfiles for more than one month
  * code cleaned
* Tue Mar 13 2007 prusnak@suse.cz
- update to 7.1.2
  * autoconf support
  * better hotplug CPU support
  - no longer assuming that CPU#0 can never be disabled
  * sar datafiles format changed to become more compact
* Thu Feb  8 2007 prusnak@suse.cz
- changed spec file to build with #norootforbuild
* Wed Feb  7 2007 prusnak@suse.cz
- update to 7.0.4
  * fixed incorrect NFS client and server statistics for sar
  * added hotplug CPU support to sar and mpstat
  * added iostat NFS statistics
- dropped obsoleted patches:
  * sysstat-6.0.2-hz.diff
* Thu Dec  7 2006 prusnak@suse.cz
- added procmail to Requires [#226503]
* Mon Aug  7 2006 ro@suse.de
- fix one more place with HZ usage
* Fri Jul 28 2006 olh@suse.de
- sysstat bootscript depends on boot.rootfsck, optional $local_fs (#181972)
* Tue Apr 25 2006 mjancar@suse.cz
- use sysconf(_SC_CLK_TCK) to get correct HZ (#168604)
* Fri Mar 24 2006 anicka@suse.cz
- fix bug in sysstat-6.0.2.diff [#155329]
- package file /usr/lib/sa/sa2
* Thu Jan 26 2006 mjancar@suse.cz
- prune old files (#136703)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 12 2006 majncar@suse.cz
- update to 6.0.2
* Thu Oct 13 2005 mjancar@suse.cz
- update to 6.0.1
- split patches by subject
* Sat Apr  9 2005 aj@suse.de
- Compile with GCC4.
* Thu Feb 24 2005 mjancar@suse.cz
- remove .cron from the crontab filename (#64225)
* Fri Sep  3 2004 tcrhak@suse.cz
- update to 5.0.6
* Mon Aug  9 2004 tcrhak@suse.cz
- update to 5.0.5
* Wed Jun 30 2004 tcrhak@suse.cz
- changed isag data file mask according to sa file naming
  (patch mask, bug #41691)
* Tue Mar 30 2004 tcrhak@suse.cz
- fixed insecure tmp file handling in isag (bug #35103, patch isag)
- do not install crontab directly into /etc/cron.d, but create/remove
  symlink threre during start/stop in the init script (bug #33279)
- added rcsysstat
- fixed sa1 and sa2
* Wed Feb 18 2004 tcrhak@suse.cz
- update to version 5.0.1
* Fri Sep 12 2003 tcrhak@suse.cz
- fix for systems with more than 32 cpus and a lot of memory
  [bug #30561] patch bumper
* Wed Aug 20 2003 tcrhak@suse.cz
- added LSB comments to init script [bug #24541]
* Wed Jul 23 2003 tcrhak@suse.cz
- do not log running /usr/lib/sa/sa1 every 10 minutes [bug #27253]
* Sun Jun  1 2003 ro@suse.de
- remove unpackaged files from buildroot
* Mon Mar 10 2003 tcrhak@suse.cz
- added isag script and man page
- be more descriptive in an error message (patch msg)
* Thu Feb 27 2003 tcrhak@suse.cz
- require $local_fs for start in init script [bug #24400]
  (patch init)
* Mon Feb 17 2003 tcrhak@suse.cz
- updated to version 4.0.7
- moved helper binary and scripts
  back to /usr/lib [bug #21713]
* Fri Sep  6 2002 tcrhak@suse.cz
- bug #18901:
  - use proper libdir (lib/lib64) in cron, scripts and man pages
  - in /etc/init.d/sysstat: no option b, test exit
    status of sadc, remove lockfile and be verbose
* Tue Aug  6 2002 kukuk@suse.de
- Don't start programs in post-install
- Add PreRequiers for insserv and fillup
* Thu Feb  7 2002 tcrhak@suse.cz
- another %%{_libdir} fix
* Thu Jan 31 2002 tcrhak@suse.cz
- update to 4.0.3
- refined scripts sa1 and sa2 to handle lockfile safe
* Fri Jan 18 2002 tcrhak@suse.cz
- used macros %%{_lib} and %%{_libdir}
* Tue Dec 18 2001 tcrhak@suse.cz
- update to version 4.0.2
- fixed bug #12664
- added dependecy on gnuplot
- adapted spec to use fillup_and_insserv/insserv_cleanup staff
* Mon Aug 20 2001 adostal@suse.cz
- update to version 4.0.1
- update patch
* Tue May 15 2001 pblaha@suse.cz
- add file lock for scripts sa1 and sa2 for fix bug #7861
* Thu May  3 2001 pblaha@suse.cz
- use sa.%%Y_%%m_%%d format for sar command
* Sun Apr 15 2001 schwab@suse.de
- Use getpagesize() instead of PAGE_SHIFT.
* Thu Apr 12 2001 pblaha@suse.cz
- update on 4.0.0
* Wed Mar 21 2001 schwab@suse.de
- Use getpagesize() instead of PAGE_SHIFT.
* Thu Dec  7 2000 nadvornik@suse.de
- fixed init script
* Wed Dec  6 2000 nadvornik@suse.cz
- fixed sa1 and sa2 scripts
- fixed cron files
* Sat Dec  2 2000 smid@suse.cz
- new version 3.3.2
* Thu Oct 19 2000 smid@suse.cz
- new version 3.3.1
* Thu Jun  8 2000 nadvornik@suse.cz
- fixed clean section
* Fri May  5 2000 smid@suse.cz
- upgrade to 3.2
- buildroot added
* Tue Jan 18 2000 nashif@suse.de
- Initial release (Version 2.2)
